AgentLoop

Struct AgentLoop 

pub struct AgentLoop<M: CompletionModel> { /* private fields */ }

Implementations

Source

impl<M: CompletionModel> AgentLoop<M>

pub fn new( agent: Agent<M>, prompt_stream: impl Stream<Item = CompletionEvaluatedPrompt> + 'static, ) -> Self

Creates a new Coral agent loop

pub fn iteration_tool_quota(self, iteration_tool_quota: Option<u32>) -> Self

The maximum number of tools that can be used during one iteration. If an iteration reaches this limit, it will move on to the next iteration. This number should be large enough to allow the model to use as many tools as it needs to complete a task, but should also be small enough to catch any bugs that result in infinite tool usage.

If None is provided, there will be no limit to tool usage. If there is an infinite tool usage bug when None is set, tokens will be burned! Default is DEFAULT_ITERATION_TOOL_QUOTA

pub async fn execute(self) -> Result<(), Error>

Executes the loop, consuming self